@@ -1,11 +1,14 @@
+import contextlib
 import json
 import uuid
 from typing import Dict, List, Mapping, Optional
 
+import httpx
 import pytest
 import respx
 from httpx import Response
 from jwcrypto import jwk
+from pytest_mock import MockerFixture
 
 from fief_client.client import (
     Fief,
@@ -54,22 +57,77 @@ def test_serializable_fief_token_response():
     )
 
 
+class TestCustomVerifyCertParameters:
+    def test_sync(self, mocker: MockerFixture):
+        client_mock = mocker.patch.object(httpx, "Client")
+
+        fief = Fief(
+            "https://bretagne.fief.dev",
+            "CLIENT_ID",
+            "CLIENT_SECRET",
+            verify=False,
+            cert="/bretagne.pem",
+        )
+        with fief._get_httpx_client() as _:
+            client_mock.assert_called_with(
+                base_url="https://bretagne.fief.dev",
+                headers={},
+                verify=False,
+                cert="/bretagne.pem",
+            )
+
+    @pytest.mark.asyncio
+    async def test_async(self, mocker: MockerFixture):
+        client_mock = mocker.patch.object(httpx, "AsyncClient")
+
+        @contextlib.asynccontextmanager
+        async def client_context_mock(*args, **kwargs):
+            yield
+
+        client_mock.side_effect = client_context_mock
+
+        fief = FiefAsync(
+            "https://bretagne.fief.dev",
+            "CLIENT_ID",
+            "CLIENT_SECRET",
+            verify=False,
+            cert="/bretagne.pem",
+        )
+        async with fief._get_httpx_client() as _:
+            client_mock.assert_called_with(
+                base_url="https://bretagne.fief.dev",
+                headers={},
+                verify=False,
+                cert="/bretagne.pem",
+            )
+
+
 class TestAuthURL:
     @pytest.mark.parametrize(
-        "state,scope,code_challenge,code_challenge_method,extras_params,expected_params",
+        "state,scope,code_challenge,code_challenge_method,lang,extras_params,expected_params",
         [
-            (None, None, None, None, None, ""),
-            ("STATE", None, None, None, None, "&state=STATE"),
-            (None, ["SCOPE_1", "SCOPE_2"], None, None, None, "&scope=SCOPE_1+SCOPE_2"),
-            (None, None, None, None, {"foo": "bar"}, "&foo=bar"),
+            (None, None, None, None, None, None, ""),
+            ("STATE", None, None, None, None, None, "&state=STATE"),
+            (
+                None,
+                ["SCOPE_1", "SCOPE_2"],
+                None,
+                None,
+                None,
+                None,
+                "&scope=SCOPE_1+SCOPE_2",
+            ),
+            (None, None, None, None, None, {"foo": "bar"}, "&foo=bar"),
             (
                 None,
                 None,
                 "CODE_CHALLENGE",
                 "S256",
                 None,
+                None,
                 "&code_challenge=CODE_CHALLENGE&code_challenge_method=S256",
             ),
+            (None, None, None, None, "fr-FR", None, "&lang=fr-FR"),
         ],
     )
     def test_authorization_url(
@@ -78,6 +136,7 @@ class TestAuthURL:
         scope: Optional[List[str]],
         code_challenge: Optional[str],
         code_challenge_method: Optional[str],
+        lang: Optional[str],
         extras_params: Optional[Mapping[str, str]],
         expected_params: str,
         fief_client: Fief,
@@ -89,6 +148,7 @@ class TestAuthURL:
             scope=scope,
             code_challenge=code_challenge,
             code_challenge_method=code_challenge_method,
+            lang=lang,
             extras_params=extras_params,
         )
         assert (
@@ -105,20 +165,30 @@ class TestAuthURL:
 
     @pytest.mark.asyncio
     @pytest.mark.parametrize(
-        "state,scope,code_challenge,code_challenge_method,extras_params,expected_params",
+        "state,scope,code_challenge,code_challenge_method,lang,extras_params,expected_params",
         [
-            (None, None, None, None, None, ""),
-            ("STATE", None, None, None, None, "&state=STATE"),
-            (None, ["SCOPE_1", "SCOPE_2"], None, None, None, "&scope=SCOPE_1+SCOPE_2"),
-            (None, None, None, None, {"foo": "bar"}, "&foo=bar"),
+            (None, None, None, None, None, None, ""),
+            ("STATE", None, None, None, None, None, "&state=STATE"),
+            (
+                None,
+                ["SCOPE_1", "SCOPE_2"],
+                None,
+                None,
+                None,
+                None,
+                "&scope=SCOPE_1+SCOPE_2",
+            ),
+            (None, None, None, None, None, {"foo": "bar"}, "&foo=bar"),
             (
                 None,
                 None,
                 "CODE_CHALLENGE",
                 "S256",
                 None,
+                None,
                 "&code_challenge=CODE_CHALLENGE&code_challenge_method=S256",
             ),
+            (None, None, None, None, "fr-FR", None, "&lang=fr-FR"),
         ],
     )
     async def test_authorization_url_async(
@@ -127,6 +197,7 @@ class TestAuthURL:
         scope: Optional[List[str]],
         code_challenge: Optional[str],
         code_challenge_method: Optional[str],
+        lang: Optional[str],
         extras_params: Optional[Mapping[str, str]],
         expected_params: str,
         fief_async_client: FiefAsync,
@@ -138,6 +209,7 @@ class TestAuthURL:
             scope=scope,
             code_challenge=code_challenge,
             code_challenge_method=code_challenge_method,
+            lang=lang,
             extras_params=extras_params,
         )
         assert (
